import * as React from 'react';
export declare const UNKNOWN_COMPONENT = "unknown";
export declare type FallbackRender = (errorData: {
    error: Error;
    componentStack: string | null;
    eventId: string | null;
    resetError(): void;
}) => React.ReactElement;
export declare type ErrorBoundaryProps = {
    children?: React.ReactNode | (() => React.ReactNode);
    /**
     * A fallback component that gets rendered when the error boundary encounters an error.
     *
     * Can either provide a React Component, or a function that returns React Component as
     * a valid fallback prop. If a function is provided, the function will be called with
     * the error, the component stack, and a function that resets the error boundary on error.
     *
     */
    fallback?: React.ReactElement | FallbackRender;
    /** Called when the error boundary encounters an error */
    onError?(error: Error, componentStack: string, eventId: string): void;
    /** Called on componentDidMount() */
    onMount?(): void;
    /** Called if resetError() is called from the fallback render props function  */
    onReset?(error: Error | null, componentStack: string | null, eventId: string | null): void;
    /** Called on componentWillUnmount() */
    onUnmount?(error: Error | null, componentStack: string | null, eventId: string | null): void;
};
declare type ErrorBoundaryState = {
    componentStack: React.ErrorInfo['componentStack'] | null;
    error: Error | null;
    eventId: string | null;
};
/**
 * A ErrorBoundary component that logs errors to Noibu. Requires React >= 16.
 */
declare class ErrorBoundary extends React.Component<ErrorBoundaryProps, ErrorBoundaryState> {
    state: ErrorBoundaryState;
    /**
     * Lifecycle hook on mount
     * @returns void
     */
    componentDidMount(): void;
    /**
     *
     * Handler for all errors that happen in a wrapped component
     * @param  {Error&{cause?:Error}} error
     * @param  {React.ErrorInfo} {componentStack}
     * @returns void
     */
    componentDidCatch(error: Error & {
        cause?: Error;
    }, { componentStack }: React.ErrorInfo): void;
    /**
     *  * Lifecycle hook on unmount
     * @returns void
     */
    componentWillUnmount(): void;
    /**
     * Callback from fallback to reset the error boundary
     * @param  {} =>void=(
     */
    resetErrorBoundary: () => void;
    /**
     *
     * Renders the fallback ui
     * @returns React
     */
    render(): React.ReactNode;
}
export { ErrorBoundary };
